# Candy Crush Life Bot

## Overview
This project automates sending lives to friends on Candy Crush Soda Saga. 
This is accomplished by creating a web bot using Selenium. 
Selenium allows us to automate interactions with a web browser, so we use Selenium 
to automatically press buttons/select options in the web-based version of
Candy Crush Soda Saga to send lives to friends.